@@ -13,10 +13,13 @@ Search::Xapian::DatabaseOpeningError -  DatabaseOpeningError indicates failure t
 use 5.006;
 use strict;
 use warnings;
-use Carp;
 
 require DynaLoader;
 
+# For compatibility with XS Search::Xapian < 1.2.3 which still threw strings
+# in some cases.
+use overload '""' => sub { "Exception: ".$_[0]->get_msg };
+
 use Search::Xapian::DatabaseVersionError;
 
 our @ISA = qw(DynaLoader Search::Xapian::DatabaseError);
